Rename library and update build system

Change-Id: I78c6a412c5e2181e58649c0e0aa2aa2f97da16a1
diff --git a/src/group-manager.cpp b/src/group-manager.cpp
index dfcb260..0521dff 100644
--- a/src/group-manager.cpp
+++ b/src/group-manager.cpp
@@ -1,24 +1,20 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /**
- * Copyright (c) 2014-2018,  Regents of the University of California
+ * Copyright (c) 2014-2018, Regents of the University of California
  *
  * This file is part of ndn-group-encrypt (Group-based Encryption Protocol for
  * NDN). See AUTHORS.md for complete list of ndn-group-encrypt authors and
  * contributors.
  *
  * ndn-group-encrypt is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation, either version 3 of the License, or (at your option) any
  * later version.
  *
- * ndn-group-encrypt is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * NAC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * ndn-group-encrypt, e.g., in COPYING.md file.  If not, see
- * <http://www.gnu.org/licenses/>.
+ * NAC, e.g., in COPYING.md file.  If not, see <http://www.gnu.org/licenses/>.
  *
  * @author Zhiyi Zhang <zhiyi@cs.ucla.edu>
  */
@@ -33,7 +29,7 @@
 #include <ndn-cxx/util/string-helper.hpp>
 
 namespace ndn {
-namespace gep {
+namespace nac {
 
 GroupManager::GroupManager(const Name& prefix,
                            const Name& dataType,
@@ -260,5 +256,5 @@
   m_db.cleanEKeys();
 }
 
-} // namespace gep
+} // namespace nac
 } // namespace ndn
@@ -1,24 +1,20 @@
  *
- * This file is part of ndn-group-encrypt (Group-based Encryption Protocol for
- * NDN). See AUTHORS.md for complete list of ndn-group-encrypt authors and
- * contributors.
+ * This file is part of NAC (Name-Based Access Control for NDN).
+ * See AUTHORS.md for complete list of NAC authors and contributors.
  *
@@ -1,24 +1,20 @@
  *
- * ndn-group-encrypt is free software: you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
+ * NAC is free software: you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software Foundation,
+ * either version 3 of the License, or (at your option) any later version.
  *